@@ -6,14 +6,15 @@
 
 #include "powerdevilapp.h"
 
+#include "powerdevilcore.h"
 #include "powerdevilfdoconnector.h"
-#include "powermanagementadaptor.h"
-#include "powermanagementpolicyagentadaptor.h"
+#include "powerdevilscreenbrightnessagent.h"
+
+#include <powermanagementadaptor.h>
+#include <powermanagementpolicyagentadaptor.h>
 
 #include "powerdevil_debug.h"
 #include "powerdevil_version.h"
-#include "powerdevilcore.h"
-#include "../osd/osd.h"
 
 #include <QAction>
 #include <QDBusConnection>
@@ -29,11 +30,10 @@
 #include <KDBusService>
 #include <KLocalizedString>
 
-#include <KActionCollection>
-#include <KGlobalAccel>
-
 #include <qnamespace.h>
 
+using namespace Qt::StringLiterals;
+
 PowerDevilApp::PowerDevilApp(int &argc, char **argv)
     : QGuiApplication(argc, argv)
     , m_core(nullptr)
@@ -42,6 +42,7 @@ PowerDevilApp::PowerDevilApp(int &argc, char **argv)
 
 PowerDevilApp::~PowerDevilApp()
 {
+    QDBusConnection::sessionBus().unregisterObject(u"/org/kde/ScreenBrightness"_s, QDBusConnection::UnregisterTree);
     delete m_core;
 }
 
@@ -86,7 +87,7 @@ void PowerDevilApp::onCoreReady()
     QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.Solid.PowerManagement"));
     QDBusConnection::sessionBus().registerObject(QLatin1String("/org/kde/Solid/PowerManagement"), m_core);
 
-    QDBusConnection::systemBus().interface()->registerService("org.freedesktop.Policy.Power");
+    QDBusConnection::systemBus().interface()->registerService(u"org.freedesktop.Policy.Power"_s);
 
     // Start the Policy Agent service
     qDBusRegisterMetaType<QList<InhibitionInfo>>();
@@ -96,11 +97,9 @@ void PowerDevilApp::onCoreReady()
     QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.Solid.PowerManagement.PolicyAgent"));
     QDBusConnection::sessionBus().registerObject(QLatin1String("/org/kde/Solid/PowerManagement/PolicyAgent"), PowerDevil::PolicyAgent::instance());
 
-    KActionCollection *coll = new KActionCollection(this);
-    QAction *action = coll->addAction(QStringLiteral("powerProfile"));
-    action->setText(i18n("Switch Power Profile"));
-    KGlobalAccel::self()->setGlobalShortcut(action, QList<QKeySequence>{Qt::Key_Battery, Qt::MetaModifier | Qt::Key_B});
-    connect(action, &QAction::triggered, this, &PowerDevilApp::showOsd);
+    // Start the ScreenBrightness service
+    QDBusConnection::sessionBus().registerService(u"org.kde.ScreenBrightness"_s);
+    new PowerDevil::ScreenBrightnessAgent(m_core->screenBrightnessController(), m_core->screenBrightnessController());
 }
 
 int main(int argc, char **argv)
@@ -108,7 +107,6 @@ int main(int argc, char **argv)
     QGuiApplication::setDesktopSettingsAware(false);
     QGuiApplication::setAttribute(Qt::AA_DisableSessionManager);
     PowerDevilApp app(argc, argv);
-    KCrash::initialize();
 
     bool replace = false;
     {
@@ -131,16 +129,9 @@ int main(int argc, char **argv)
     app.setQuitOnLastWindowClosed(false);
     app.setQuitLockEnabled(false);
     app.init();
+    KCrash::initialize();
 
     return app.exec();
 }
 
-void PowerDevilApp::showOsd() {
-    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.powerdevil.powerProfileOsdService"),
-                                                          QStringLiteral("/org/kde/powerdevil/powerProfileOsdService"),
-                                                          QStringLiteral("org.kde.powerdevil.powerProfileOsdService"),
-                                                          QStringLiteral("showOsd"));
-    QDBusConnection::sessionBus().asyncCall(message);
-}
-
 #include "moc_powerdevilapp.cpp"
